function [overlapping, overlaparea] = CheckCircleOverlap(r, R, y1, y2)
    % function [overlapping, overlaparea] = CheckCircleOverlap(r, R, y1, y2)
    %
    % Calculates if two circles on the same axis are overlapping or not,
    % and if they are, how much area is shared between the two circles.
    %    r - radius of circle one (m)
    %    R - radius of circle two (m)
    %    y1 - location of circle one along a line (m)
    %    y2 - location of circle two along the same line (m)
    %
    %    overlapping - 0 if no overlap, 1 if circles overlap, 2 if circle
    %    one is entirely inside of circle two, 3 if circle two is entirely
    %    inside of circle one
    %    overlaparea - the overlapping area (m2)
    % See https://mathworld.wolfram.com/Circle-CircleIntersection.html for
    % more details

    d = abs(y2 - y1);
    if d > (r + R)
        % No overlap
        overlapping = 0;
        overlaparea = 0;
    else
        
        if r + d < R % r is inside of R
            overlapping = 2;
            overlaparea = pi*r^2;
        elseif  R + d < r % R is inside of r
            overlapping = 3;
            overlaparea = pi*R^2;
        else
            overlapping = 1;
            overlaparea = r^2*acos((d^2+r^2-R^2)/(2*d*r)) + ...
                          R^2*acos((d^2+R^2-r^2)/(2*d*R)) - ...
                          0.5*sqrt((-d+r+R)*(d+r-R)*(d-r+R)*(d+r+R));
        end
              
        if ~isreal(overlaparea)
            error('The overlapped area is imaginary')
        end
    end