function mh = FlowRates(mh)
    % function mh = FlowRates(mh)
    %
    % Use the manhole geometry specified within a manhole struct (mh) to
    % calculate the exchange between zones
    
    constants

    % Assume manhole outflow is equal to inflow (i.e., steady state conditions)
    mh.Qout = mh.Qin;
    
    mh.Q01 = mh.Qin;

    if mh.angle == 0 && mh.step == 0 && mh.benched == 0
        mh = StraightFlowRates(mh);
    elseif mh.angle == 0 && mh.step ~= 0 && mh.benched == 0
        mh = SteppedFlowRates(mh);
    elseif mh.angle ~= 0 && mh.step == 0 && mh.benched == 0
        mh = AngledFlowRates(mh);
    else
        error('Manhole type not recognised')
    end
    
    % Calculate Q32 as what's left over knowing the other flow rates as Q12
    % and Q42 are both easier to calculate than Q32
    mh.Q32 = mh.Qout - mh.Q12 - mh.Q42; % Equation 21, rearranged
    mh.Q34 = (mh.Q3 - mh.Q3c - mh.Q3d) - mh.Q32; % Equation 20, Q3 at this point accounts for Q3c and Q3c
    mh.Q43 = mh.Q34 - mh.Q42; % Equation 22

    if mh.V5 ~= 0
        mh.Q45 = mh.Q43; % Equation 23
        mh.Q54 = mh.Q45;
    else
        mh.Q45 = 0;
        mh.Q54 = 0;
    end
    
    if mh.Q12 < 0 || mh.Q32 < 0 || mh.Q34 < 0 || mh.Q43 < 0
        error('Negative flow rate detected')
    end
