function mh = Manhole(Dp, Dm, S, Qin, toMeasurement, angle, step, benched, mh)
    % function mh = Manhole(Dp, Dm, S, Qin, [toMeasurement], [angle], [step], [benched], [mh])
    %
    % Create a manhole struct (mh) containing manhole geometry information.
    %    Dp - manhole inlet and outlet diameter (m)
    %    Dm - manhole diameter (m)
    %    S - manhole surcharge above inlet soffit (m)
    %    toMeasurement - distance from manhole inlet to measurement device (m, assumed 0)
    %    angle - outlet angle (assumed 0)
    %    step - difference in elevation between inlet and outlet invert (m)
    %    benched - 0 for unbenched, assumed, set to 1 for benched manholes
    %    mh - if a manhole struct is passed as an argument, edit that
    %    existing struct rather than create a new struct

    if ~exist('mh', 'var')
        mh = struct();
    end
    mh.Dp = Dp;
    mh.Dm = Dm;
    mh.S = S;
    mh.Qin = Qin;
    
    if ~exist('toMeasurement', 'var')
        % toFluoro is the distance from the manhole centre to measurement
        % this needs to be at least the manhole inlet/outlet
        toFluoro = Dm/2;
    else
        toFluoro = Dm/2 + toMeasurement;
    end
    if ~exist('angle', 'var')
        angle = 0;
    end
    if ~exist('step', 'var')
        step = 0;
    end
    if ~exist('benched', 'var')
        benched = 0;
    end
    
    mh.toFluoro = toFluoro;
    mh.angle = angle;
    mh.step = step;
    mh.benched = benched;
    
