function PlotFlows(mh, allpercentages)
    % function PlotFlows(mh, [allpercentages])
    %
    % Plot a diagram showing the relative flow rates between manhole zones
    % contained in the mh struct. Set [allpercentages] to 0 to turn off
    % showing 0 percents.

    if ~exist('allpercentages', 'var')
        allpercentages = 1;
    end
    
    im = imread('block diagram.png');
    if exist('insertText', 'file') == 0
        % Show the image then use regular text labels
        imshow(im)
    end
    
    im = doText(im, [120 645], sprintf('%0.3f\nm3/s', mh.Qin), 'RightCenter');
    if mh.Qout ~= mh.Qin
        im = doText(im, [795 645], sprintf('%0.2f%%', mh.Qout/mh.Qin*100), 'LeftCenter');
    end
        
    if isfield(mh, 'Q45') && (mh.Q45 ~= 0 || allpercentages == 1)
        im = doText(im, [430 160], sprintf('%0.2f%%', mh.Q45/mh.Qin*100), 'LeftCenter');
        im = doText(im, [210 160], sprintf('%0.2f%%', mh.Q54/mh.Qin*100), 'RightCenter');
    end
    
    if mh.Q34 ~= 0 || allpercentages == 1
        im = doText(im, [430 350], sprintf('%0.2f%%', mh.Q34/mh.Qin*100), 'LeftCenter');
    end
    if mh.Q43 ~= 0 || allpercentages == 1
        im = doText(im, [210 350], sprintf('%0.2f%%', mh.Q43/mh.Qin*100), 'RightCenter');
    end
    
    if mh.Q01 ~= 0 || allpercentages == 1
        im = doText(im, [160 590], sprintf('%0.2f%%', mh.Q01/mh.Qin*100), 'CenterBottom');
    end
    
    if mh.Q13 ~= 0 || allpercentages == 1
        im = doText(im, [370 520], sprintf('%0.2f%%', mh.Q13/mh.Qin*100), 'LeftCenter');
    end
        
    if mh.Q12 ~= 0 || allpercentages == 1
        im = doText(im, [455 590], sprintf('%0.2f%%', mh.Q12/mh.Qin*100), 'CenterBottom');
    end
    if mh.Q32 ~= 0 || allpercentages == 1
        im = doText(im, [550 430], sprintf('%0.2f%%', mh.Q32/mh.Qin*100), 'CenterBottom');
    end
    if mh.Q42 ~= 0 || allpercentages == 1
        im = doText(im, [605 260], sprintf('%0.2f%%', mh.Q42/mh.Qin*100), 'CenterBottom');
    end
    
    if exist('insertText', 'file') > 0
        % Draw text on the image then display that
        imshow(im, 'Interpolation', 'bilinear')
    end
   
            
    function im = doText(im, pos, txt, ap)

        if exist('insertText', 'file') > 0
            % User insertText() from the computer vision toolbox if it's available
            im = insertText(im, pos, txt, 'FontSize', 20, 'AnchorPoint', ap);

        else
            % Otherwise, use a regular text label (Octave will use this)
            if ~isempty(strfind(lower(ap), 'right')) %#ok<STREMP>
                ha = 'right';
            elseif ~isempty(strfind(lower(ap), 'center')) && lower(ap(1)) == 'c' %#ok<STREMP>
                ha = 'center';
            else
                ha = 'left';
            end

            if ~isempty(strfind(lower(ap), 'bottom')) %#ok<STREMP>
                va = 'bottom';
            elseif ~isempty(strfind(lower(ap), 'top')) %#ok<STREMP>
                va = 'top';
            else
                va = 'middle';
            end

            text(pos(1), pos(2), txt, 'FontSize', 11, 'HorizontalAlignment', ha, 'VerticalAlignment', va)
            
        end
       
