function mh = SetupManhole(mh)
    % function mh = SetupManhole(mh)
    %
    % Use the manhole dimensions specified within a manhole struct (mh) to
    % calculate the zone volumes and flow rates for exchange between zones

    constants

    % Setup manhole zone volumes
    if mh.angle == 0 && mh.step == 0 && mh.benched == 0
        mh = StraightManhole(mh);
    elseif mh.angle == 0 && mh.step ~= 0 && mh.benched == 0
        mh = SteppedManhole(mh);
    elseif mh.angle ~= 0 && mh.step == 0 && mh.benched == 0
        % The zone geometry for an angled manhole is the same for as a
        % straight through manhole
        mh = StraightManhole(mh);
    else
        error('Manhole type not recognised')
    end
    
    % Add the high surcharge zone if needed
    if mh.S > mh.Dm
        if (mh.S - mh.Dm)*mh.Dm^2/4 < mh.Qin/1000*0.01
            % V5 needs to be at least big enough to exchange
            mh.V5 = mh.Qin/1000*0.1;
        else
            mh.V5 = pi*(mh.S - mh.Dm)*mh.Dm^2/4; % Equation 8
        end
    else
        mh.V5 = 0;
    end
    mh.V4 = mh.V4 - mh.V5; % Equation 7

    % Calculate flow rates between zones
    mh = FlowRates(mh);

    % Calculate time delay
    mh.U = mh.Qin / (mh.Dp^2*pi/4);
    mh.timedelay = (mh.toFluoro*2-mh.Dm)/(mh.U*Umax_ratio);
