function mh = AngledFlowRates(mh)
    % function mh = AngledFlowRates(mh)
    %
    % Use the manhole geometry specified within a manhole struct (mh) to
    % calculate the exchange between zones for an angled manhole
    
    constants
        
    mh.Q12 = 0;
    mh.Q13 = mh.Q01;
    
    % Note, this is largely copied from StraightFlowRates
    if mh.Dm / mh.Dp < 1/(2*alpha2) % The jet core reaches the outlet

        % Assume the jet hits the wall, so this needs to be added to Q3
        Q12 = mh.Qin*(1 - 4*alpha2*mh.Dm/mh.Dp + 4*(alpha2*mh.Dm/mh.Dp)^2);
        
        mh.Q3c = mh.Qin*(2*alpha2*mh.Dm/mh.Dp)^2*(1-erf(1/sqrt(2))); % Equation 13
        if mh.S < mh.Dm/m
            mh.Q3d = mh.Qin*(2*alpha2*mh.Dm/mh.Dp)^2*(1-erf((alpha2*mh.Dm+mh.S)/(sqrt(2)*alpha2*mh.Dm))); % Equation 14
        else
            mh.Q3d = 0;
        end

        mh.Q3 = mh.Qin*2*(alpha2*mh.Dm/mh.Dp)^2*...
            (4+(sqrt(2*pi)*(mh.Dp-2*alpha2*mh.Dm))/(alpha2*mh.Dm)) + Q12; % Equation 12
    else % The jet core does not reach the outlet (a wide manhole)
        
        mh.Q3c = mh.Qin*2*alpha2*mh.Dm/mh.Dp*erfc(mh.Dp/(2*sqrt(2)*alpha2*mh.Dm)); % Equation 17
        if mh.S < mh.Dm/m
            mh.Q3d = mh.Qin*2*alpha2*mh.Dm/mh.Dp*erfc((mh.Dp+2*mh.S)/(2*sqrt(2)*alpha2*mh.Dm)); % Equation 18
        else
            mh.Q3d = 0;
        end

        mh.Q3 = mh.Qin*4*alpha2*mh.Dm/mh.Dp; % Equation 16
    end
    
    % The intersection of jet diffusion zone edge with the manhole wall, so
    % also the radius of the jet diffusion zone at the outlet, Equation 25
    x3 = (-mh.Dm - m*mh.Dp + sqrt(-2*mh.Dm*mh.Dp*m^3 + mh.Dm^2*m^4 - mh.Dp^2*m^4))/(2*(1+m^2));
    y3 = x3/m + mh.Dp/2 + mh.Dm/(2*m);
        
    % The transverse location of edges of outlet, Equation 24
    yo = mh.Dm/2 * sind(mh.angle) + [-1 1]*mh.Dp/2 * cosd(-mh.angle);
    
    if y3 > yo(1) && y3 < yo(2)
        % The jet diffusion zone cuts the outlet
        
        % Assume the minor chord of the ellipse that is the rotated outlet
        % is instead the radius of ta smaller circle, this is an
        % estimated approximation.
        effectiver = mh.Dp/2*cosd(mh.angle);
        
        % The location of center of outlet
        yoc = mh.Dm/2 * sind(mh.angle);

        % Check the overlap of the assumed outlet circle and jet diffusion
        % zone to work out flow contributions
        [~, overlaparea] = CheckCircleOverlap(effectiver, y3, yoc, 0);
        overlapfraction = overlaparea/(pi*effectiver^2);
        mh.Q42 = mh.Qout*(1-overlapfraction);
        
    elseif yo(1) < mh.Dp/2-mh.Dm*alpha2
        error('Equations and code for outlet within jet core need to be written')
        % Equation 26 would be involved here
        
    elseif y3 < yo(1)
        % The outlet is entirely in the outer mixing zone
        mh.Q42 = mh.Qout;
        
    elseif y3 > yo(2)
        % The outlet is entirely in the jet diffusion zone
        mh.Q42 = 0;
        
    else
        error('Problem finding the relation between the outlet and the jet diffusion zone')
    end
    
