function mh = SteppedManhole(mh)
    % function mh = SteppedManhole(mh)
    %
    % Use the manhole dimensions specified within a manhole struct (mh) to
    % calculate the zone volumes for a straight through, but stepped, manhole
    
    constants
    
    if mh.Dm / mh.Dp > 1/(2*alpha2)
        error('Equations and code for large stepped manholes need to be written')
    end
    
    % Radius of the jet core at the outlet, needed for determining the
    % overlap of the zones at the outlet
    mh.jetcoreradius = mh.Dp/2-mh.Dm*alpha2;
    
    mh.V1b = -pi*(-0.5*mh.Dp+alpha2*mh.Dm)^3/(3*alpha2); % Equation 2
    mh.V1 = pi*mh.Dp^3/(24*alpha2) - mh.V1b; % Equation 1
    
    mh.V3b = m*pi*mh.Dp^3/24; % Equation 4
    
    % If the offset jet expansion zone goes below the bottom of the
    % manhole, subtract that volume as V3c
    if -mh.Dp/2 - mh.Dm/m < - mh.Dp/2 - mh.step
        mh.V3c = ((m*mh.Dp/2 + mh.Dm)/(3*(mh.Dp/2+mh.Dm/m)))*( ...
                (0.5*mh.Dp + mh.Dm/m)^3*acos((mh.Dp/2+mh.step)/(mh.Dp/2+mh.Dm/m)) - ...
                2*(0.5*mh.Dp+mh.Dm/m)*(mh.Dp/2+mh.step)*sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2+mh.step)^2) + ...
                ((mh.Dp/2+mh.step)^3)*log(((0.5*mh.Dp+mh.Dm/m) + sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2+mh.step)^2))/(mh.Dp/2+mh.step)) ...
            ); % Equation 5, offset by the manhole step
    else
        mh.V3c = 0;
    end
    
    if mh.S < mh.Dm/m
        mh.V3d = ((m*mh.Dp/2 + mh.Dm)/(3*(mh.Dp/2+mh.Dm/m)))*( ...
                (0.5*mh.Dp + mh.Dm/m)^3*acos((mh.Dp/2+mh.S)/(mh.Dp/2+mh.Dm/m)) - ...
                2*(0.5*mh.Dp+mh.Dm/m)*(mh.Dp/2+mh.S)*sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2+mh.S)^2) + ...
                ((mh.Dp/2+mh.S)^3)*log(((0.5*mh.Dp+mh.Dm/m) + sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2+mh.S)^2))/(mh.Dp/2+mh.S)) ...
            ); % Equation 6
    else
        mh.V3d = 0;
    end
    
    mh.V3 = (pi/3)*(mh.Dp/2 + mh.Dm/m)^2*(m*mh.Dp/2+mh.Dm) - mh.V3b - mh.V3c - mh.V3d - mh.V1; % Equation 3
    
    mh.V4 = pi*(mh.S + mh.Dp + mh.step)*mh.Dm^2/4 - mh.V3 - mh.V1; % Equation 7
    
    % The volume of the manhole plus and lengths of pipe on either side
    mh.SystemV = mh.V1 + mh.V3 + mh.V4 + 2 * (mh.toFluoro - mh.Dm/2) .* mh.Dp.^2 * pi / 4;
