function mh = StraightFlowRates(mh)
    % function mh = StraightFlowRates(mh)
    %
    % Use the manhole geometry specified within a manhole struct (mh) to
    % calculate the exchange between zones for a straight through manhole
    
    constants

%     % Increase for a larger outlet downstream
%     if ~isfield(mh, 'effectiveDp')
%         mh.effectiveDp = mh.Dp;
%     else
%         warning('Untested code')
%     end
    
    if mh.Dm / mh.Dp < 1/(2*alpha2) % The jet core reaches the outlet
        
        mh.Q12 = mh.Qin*(1 - 4*alpha2*mh.Dm/mh.Dp + 4*(alpha2*mh.Dm/mh.Dp)^2); % Equation 9
        mh.Q13 = mh.Qin - mh.Q12; % Equation 10
        
        mh.Q3c = mh.Qin*(2*alpha2*mh.Dm/mh.Dp)^2*(1-erf(1/sqrt(2))); % Equation 13
        if mh.S < mh.Dm/m
            mh.Q3d = mh.Qin*(2*alpha2*mh.Dm/mh.Dp)^2*(1-erf((alpha2*mh.Dm+mh.S)/(sqrt(2)*alpha2*mh.Dm))); % Equation 14
        else
            mh.Q3d = 0;
        end

        mh.Q3 = mh.Qin*2*(alpha2*mh.Dm/mh.Dp)^2*...
            (4+(sqrt(2*pi)*(mh.Dp-2*alpha2*mh.Dm))/(alpha2*mh.Dm)); % Equation 12
    else % The jet core does not reach the outlet (a wide manhole)

        mh.Q12 = 0;
        mh.Q13 = mh.Q01; % Everything from the jet core goes into the jet diffusion zone
        
        mh.Q3c = mh.Qin*2*alpha2*mh.Dm/mh.Dp*erfc(mh.Dp/(2*sqrt(2)*alpha2*mh.Dm)); % Equation 17
        if mh.S < mh.Dm/m
            mh.Q3d = mh.Qin*2*alpha2*mh.Dm/mh.Dp*erfc((mh.Dp+2*mh.S)/(2*sqrt(2)*alpha2*mh.Dm)); % Equation 18
        else
            mh.Q3d = 0;
        end

        mh.Q3 = mh.Qin*4*alpha2*mh.Dm/mh.Dp; % Equation 16
    end
    
    mh.Q42 = 0; % There is no flow from the outer mixing zone to the outlet in a straight manhole
    