function mh = StraightManhole(mh)
    % function mh = StraightManhole(mh)
    %
    % Use the manhole dimensions specified within a manhole struct (mh) to
    % calculate the zone volumes for a straight through manhole
    
    constants
    
    if mh.Dm / mh.Dp < 1/(2*alpha2)
        mh.V1b = -pi*(-0.5*mh.Dp+alpha2*mh.Dm)^3/(3*alpha2); % Equation 2
    else
        % For a large manhole, nothing extends beyond the outlet
        mh.V1b = 0;
    end
    mh.V1 = pi*mh.Dp^3/(24*alpha2) - mh.V1b; % Equation 1
    
    mh.V3b = m*pi*mh.Dp^3/24; % Equation 4
    mh.V3c = ((m*mh.Dp/2 + mh.Dm)/(3*(mh.Dp/2+mh.Dm/m)))*( ...
            (0.5*mh.Dp + mh.Dm/m)^3*acos((mh.Dp/2)/(mh.Dp/2+mh.Dm/m)) - ...
            2*(0.5*mh.Dp+mh.Dm/m)*(mh.Dp/2)*sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2)^2) + ...
            ((mh.Dp/2)^3)*log(((0.5*mh.Dp+mh.Dm/m) + sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2)^2))/(mh.Dp/2)) ...
        ); % Equation 5
    
    if mh.S < mh.Dm/m
        mh.V3d = ((m*mh.Dp/2 + mh.Dm)/(3*(mh.Dp/2+mh.Dm/m)))*( ...
                (0.5*mh.Dp + mh.Dm/m)^3*acos((mh.Dp/2+mh.S)/(mh.Dp/2+mh.Dm/m)) - ...
                2*(0.5*mh.Dp+mh.Dm/m)*(mh.Dp/2+mh.S)*sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2+mh.S)^2) + ...
                ((mh.Dp/2+mh.S)^3)*log(((0.5*mh.Dp+mh.Dm/m) + sqrt((mh.Dp/2 + mh.Dm/m)^2-(mh.Dp/2+mh.S)^2))/(mh.Dp/2+mh.S)) ...
            ); % Equation 6
    else
        mh.V3d = 0;
    end
    
    mh.V3 = (pi/3)*(mh.Dp/2 + mh.Dm/m)^2*(m*mh.Dp/2+mh.Dm) - mh.V3b - mh.V3c - mh.V3d - mh.V1; % Equation 3
    
    mh.V4 = pi*(mh.S + mh.Dp)*mh.Dm^2/4 - mh.V3 - mh.V1; % Equation 7
    
    % The volume of the manhole plus and lengths of pipe on either side
    mh.SystemV = mh.V1 + mh.V3 + mh.V4 + 2 * (mh.toFluoro - mh.Dm/2) .* mh.Dp.^2 * pi / 4;
